@@ -8,6 +8,6 @@ from .factor import factorint
 from .dlp import dlog
 from .ec import EC_Weierstrass
 from .la import Matrix, zeros, eye
-from .lat import gram_det, hadamard_ratio, hermite_nf, gram_schmidt, babai_round_cvp, babai_plane_cvp, lagrange_lr, lll, random_unimodular_matrix
+from .lat import gram_det, hadamard_ratio, hermite_nf, gram_schmidt, babai_round_cvp, babai_round_bnd, babai_plane_cvp, babai_plane_bnd, lagrange_lr, lll, random_unimodular_matrix
 from .poly import Poly
 from .Zmod import Zmod
