@@ -4,7 +4,7 @@ Linear algebra
 
 from math import inf, sqrt, prod
 from numbers import Number
-
+from fractions import Fraction
 
 class Matrix:
     """
@@ -148,6 +148,8 @@ class Matrix:
             for j in range(other.cols):
                 for k in range(other.rows):
                     result.matrix[i][j] += self.matrix[i][k] * other.matrix[k][j]
+        if self.rows == 1 and other.cols == 1:
+            return result.matrix[0][0]
         return result
 
     def __add__(self, other) -> "Matrix":
@@ -176,7 +178,7 @@ class Matrix:
 
     def __rmul__(self, other) -> "Matrix":
         if isinstance(other, Number) or type(other) == type(self.matrix[0][0]):
-             return Matrix([ [item * other for item in row] for row in self.matrix ])
+            return Matrix([ [item * other for item in row] for row in self.matrix ])
         return NotImplemented
 
     def rref(self) -> "Matrix":
@@ -246,6 +248,16 @@ class Matrix:
             raise ValueError("Matrix is not invertible!")
         return MM[:,n:]
 
+    def is_unimodular(self) -> bool:
+        "Test if the matrix is unimodular."
+        if self.rows != self.rows:
+            return False
+        def is_integer(i):
+            if isinstance(i, int) or (isinstance(i, Fraction) and i.denominator == 1):
+                return True
+            return False
+        return all([is_integer(i) for i in self]) and self.det()**2 == 1
+
     def zeros(self, m: int = None, n: int = None):
         "Returns a zero matrix of the same dimension"
         if not m and not n:
