@@ -1,29 +1,21 @@
 """
 Number theory tools:
-    lcm(a, b) least common mutiple of a and b
     egcd(a,b) extended Euclidean agorithm
     crt([a1, a2, ...],[m1, m2, ...]) Chinese Remainder Theorem
     cf(Fraction(m,n)) continued fraction expansions
     convergents() convergents of a continued fraction
+    legendre_symbol(a, p) compute the Legendre symbol of a with respect to the prime p
+    jacobi_symbol(a, n) compute the Jacobi symbol of a with respect to n
     sqrt_mod(n, p) square root of n modulo a prime p
     order(a, n) oder of a in the multiplicative group Z_n^*
 """
-from math import gcd, prod
+from math import gcd, lcm, prod
 from fractions import Fraction
 
-# Euclid and friends
-
-def lcm(a: int, b: int) -> int:
-    """Compute the least common multiple of a and b."""
-    if b == 0:
-        return 0
-    if bool(a > 0) != bool(b > 0):
-        a = -a
-    return (a // gcd(a, b)) * b
-
+# extended Euclid
 
 def egcd(a: int, b: int) -> (int, int, int):
-    """Perform the extended Euclidean agorithm. Returns gcd, x, y such that a x + b y = gcd."""
+    """Perform the extended Euclidean agorithm. Returns `gcd`, `x`, `y` such that `a x + b y = gcd`."""
     r0, r1 = a, b
     x0, x1, y0, y1 = 1, 0, 0, 1
     while r1 != 0:
@@ -36,8 +28,8 @@ def egcd(a: int, b: int) -> (int, int, int):
 
 # Chinese remainder theorem
 
-def crt(a: list, m: list) -> int:
-    """Solve given linear congruences x[j] % m[j] == a[j] using the Chinese Remainder Theorem."""
+def crt(a: list[int], m: list[int]) -> int:
+    """Solve given linear congruences x % m[j] == a[j] using the Chinese Remainder Theorem."""
     l = len(a)
     assert len(m) == l, "The lists of numbers and modules must have equal length."
     M = prod(m)
@@ -112,6 +104,7 @@ def crt(a: list, m: list) -> int:
 
 
 def fraction_repr(self):
+    "Representation of a fraction."
     if self.denominator == 1:
         return str(self.numerator)
     return str(self.numerator) + "/" + str(self.denominator)
@@ -178,8 +171,8 @@ def jacobi_symbol(a: int, n: int) -> int:
         return t
     return 0
 
-def sqrt_mod(a: int, p: int) -> list:
-    "Compute a square root of a modulo p unsing Cipolla's algorithm."
+def sqrt_mod(a: int, p: int) -> int:
+    "Compute a square root of `a` modulo `p` unsing Cipolla's algorithm."
     a %= p
     if a == 0 or a == 1:
         return a
@@ -211,13 +204,13 @@ from .factor import factorint
 
 
 def euler_phi(n: int) -> int:
-    """Euler's phi function of n."""
+    """Euler's phi function of `n`."""
     k = factorint(n)
     return prod([(p - 1) * p ** (k[p] - 1) for p in k])
 
 
 def carmichael_lambda(n: int) -> int:
-    """Carmichael's lambda function of n."""
+    """Carmichael's lambda function of `n`."""
     k = factorint(n)
     lam_all = []  # values corresponding to the prime factors
     for p in k:
@@ -233,10 +226,10 @@ def carmichael_lambda(n: int) -> int:
 # Order in Z_p^*
 
 def order(a: int, n: int, factor=False) -> int:
-    """Compute the order of a in the group Z_n^*."""
+    """Compute the order of `a` in the group Z_n^*."""
     a %= n
     assert a != 0 and gcd(a, n) == 1, f"{a} and {n} are not coprime!"
-    factors = dict()  # We compute euler_phi(n) and its factorization in one pass
+    factors = {}  # We compute euler_phi(n) and its factorization in one pass
     for p, k in factorint(n).items():  # first factorize n
         for pm, km in factorint(p - 1).items():  # factor p-1 and add the factors
             if pm in factors:
@@ -263,7 +256,7 @@ def order(a: int, n: int, factor=False) -> int:
             else:
                 break
         if factor and i < k:
-            factors_order[p] = k - i
+            factors_order[p] = k - i  # pylint: disable=E0606
     if factor:
         return order_a, factors_order
     return order_a
